@@ -71,7 +71,11 @@ class MarketDefinition(msgspec.Struct, kw_only=True):  # type: ignore
     status: str
     runners: List[Runner]
     regulators: List[str]
+    name: Optional[str] = None
+    openDate: Optional[str] = None
+    timezone: Optional[str] = None
     venue: Optional[str] = None
+    version: Optional[int] = None
     countryCode: Optional[str] = None
     discountAllowed: Optional[bool] = None
 
@@ -175,8 +179,8 @@ class MCM(msgspec.Struct, tag_field="op", tag=str.lower):  # type: ignore
     https://docs.developer.betfair.com/display/1smk3cen4v3lu3yomq5qye0ni/Exchange+Stream+API
     """
 
-    clk: str
     pt: int
+    clk: Optional[str] = None
     id: Optional[int] = None
     initialClk: Optional[str] = None
     status: Optional[int] = None
